package com.ruoyi.frequency.mallgoodstype.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.frequency.mallgoodstype.entity.MallGoodsType;

import java.util.List;

/**
 * 商品类型Service接口
 *
 * @author liwenlong
 * @date 2024-01-25
 */
public interface MallGoodsTypeService extends IService<MallGoodsType>
{
    /**
     * 查询商品类型
     *
     * @param id 商品类型主键
     * @return 商品类型
     */
    public MallGoodsType selectMallGoodsTypeById(Long id);

    /**
     * 查询商品类型列表
     *
     * @param mallGoodsType 商品类型
     * @return 商品类型集合
     */
    public List<MallGoodsType> selectMallGoodsTypeList(MallGoodsType mallGoodsType);

    /**
     * 新增商品类型
     *
     * @param mallGoodsType 商品类型
     * @return 结果
     */
    public int insertMallGoodsType(MallGoodsType mallGoodsType);

    /**
     * 修改商品类型
     *
     * @param mallGoodsType 商品类型
     * @return 结果
     */
    public int updateMallGoodsType(MallGoodsType mallGoodsType);

    /**
     * 批量删除商品类型
     *
     * @param ids 需要删除的商品类型主键集合
     * @return 结果
     */
    public int deleteMallGoodsTypeByIds(Long[] ids,Integer delFlag);

}
